complete -c signstar-configure-build -s c -l config -d 'The path to a custom configuration file' -r
complete -c signstar-configure-build -s v -l version -d 'Return the name and version of the application'
complete -c signstar-configure-build -s h -l help -d 'Print help (see more with \'--help\')'
